Removed PyInt_GetMax and sys.maxint
I replaced sys.maxint with sys.maxsize in Lib/*.py. Does anybody see a problem with the change on Win 64bit platforms? Win 64's long is just 32bit but the sys.maxsize is now 2**63-1 on every 64bit platform.
Also added docs for sys.maxsize.
diff --git a/Lib/mhlib.py b/Lib/mhlib.py
index 955862b..b428439 100644
--- a/Lib/mhlib.py
+++ b/Lib/mhlib.py
@@ -365,7 +365,7 @@
             try:
                 count = int(tail)
             except (ValueError, OverflowError):
                 # Can't use sys.maxint because of i+count below
                 count = len(all)
             try:
                 anchor = self._parseindex(head, all)
@@ -428,7 +428,7 @@
             try:
                 return int(seq)
             except (OverflowError, ValueError):
-                return sys.maxint
+                return sys.maxsize
         if seq in ('cur', '.'):
             return self.getcurrent()
         if seq == 'first':
@@ -365,7 +365,7 @@
                 count = int(tail)
             except (ValueError, OverflowError):
-                # Can't use sys.maxint because of i+count below
+                # Can't use sys.maxsize because of i+count below
                 count = len(all)
             try: